@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: aeson-pretty
 version: 0.7.2
-id: aeson-pretty-0.7.2-79948fcfb4ff99108a7609ce21eccf5e
-key: aeson_K96upfOIXDUKpxGYZe6f5S
+id: aeson-pretty-0.7.2-fd291a527e7a9e0cfcb7ebbe367215f0
+key: aeson_DTQ94dGtMxj46h2TfrFAzG
 license: BSD3
 copyright: Copyright 2011 Falko Peters
 maintainer: Falko Peters <falko.peters@gmail.com>
@@ -34,9 +34,9 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/aeson-pretty-0.7.2
 library-dirs: /usr/lib/ghc-7.10.3/site-local/aeson-pretty-0.7.2
 data-dir: /usr/share/arm-linux-ghc-7.10.3/aeson-pretty-0.7.2
-hs-libraries: HSaeson-pretty-0.7.2-K96upfOIXDUKpxGYZe6f5S
+hs-libraries: HSaeson-pretty-0.7.2-DTQ94dGtMxj46h2TfrFAzG
 depends:
-    aeson-0.11.1.0-01f93b6d659087121e16b9df8deda57c
+    aeson-0.11.1.1-0413068b3d94ca1008e286bfe7fa084f
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
